The branch, master has been updated
via 677e5a5da74080c0b08d8ca3e159aedc82670e76 (commit)
via 914692f56501cb2f4addc45e2d163380b4f4b34e (commit)
from 531fe9aa277e84186533af3eb27f0f7200ca577a (commit)
- Log -----------------------------------------------------------------
commit 677e5a5da74080c0b08d8ca3e159aedc82670e76
Author: Michal Čihař <michal(a)cihar.com>
Date: Tue Feb 8 22:03:18 2011 +0100
rfe #3148361 [interface] Replace hard coded limit with $cfg[LimitChars].
commit 914692f56501cb2f4addc45e2d163380b4f4b34e
Author: Michal Čihař <michal(a)cihar.com>
Date: Tue Feb 8 22:02:04 2011 +0100
Whitespace cleanup
-----------------------------------------------------------------------
Summary of changes:
ChangeLog | 1 +
tbl_change.php | 10 +++++-----
2 files changed, 6 insertions(+), 5 deletions(-)
diff --git a/ChangeLog b/ChangeLog
index 5eac03f..c0214cb 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -135,6 +135,7 @@
- [interface] Default to not count tables in database.
- patch #3172172 [interface] Shortcut for copying table row.
- bug #3175227 [auth] Reset user cache on login.
+- rfe #3148361 [interface] Replace hard coded limit with $cfg['LimitChars'].
3.3.10.0 (not yet released)
- patch #3147400 [structure] Aria table size printed as unknown,
diff --git a/tbl_change.php b/tbl_change.php
index d18f59d..713f02d 100644
--- a/tbl_change.php
+++ b/tbl_change.php
@@ -387,7 +387,7 @@ foreach ($rows as $row_id => $vrow) {
|| stripos($table_fields[$i]['Type'], 'varbinary') === 0) {
$table_fields[$i]['is_binary'] = stristr($table_fields[$i]['Type'], 'binary');
} else {
- $table_fields[$i]['is_binary'] = false;
+ $table_fields[$i]['is_binary'] = false;
}
// If check to ensure types such as "enum('one','two','blob',..)" or
@@ -398,7 +398,7 @@ foreach ($rows as $row_id => $vrow) {
|| stripos($table_fields[$i]['Type'], 'longblob') === 0) {
$table_fields[$i]['is_blob'] = stristr($table_fields[$i]['Type'], 'blob');
} else {
- $table_fields[$i]['is_blob'] = false;
+ $table_fields[$i]['is_blob'] = false;
}
// If check to ensure types such as "enum('one','two','char',..)" or
@@ -407,7 +407,7 @@ foreach ($rows as $row_id => $vrow) {
|| stripos($table_fields[$i]['Type'], 'varchar') === 0) {
$table_fields[$i]['is_char'] = stristr($table_fields[$i]['Type'], 'char');
} else {
- $table_fields[$i]['is_char'] = false;
+ $table_fields[$i]['is_char'] = false;
}
$table_fields[$i]['first_timestamp'] = false;
@@ -899,8 +899,8 @@ foreach ($rows as $row_id => $vrow) {
<?php
} else {
- // field size should be at least 4 and max 40
- $fieldsize = min(max($field['len'], 4), 40);
+ // field size should be at least 4 and max $cfg['LimitChars']
+ $fieldsize = min(max($field['len'], 4), $cfg['LimitChars']);
echo "\n";
echo $backup_field . "\n";
?>
hooks/post-receive
--
phpMyAdmin